.. SPDX-FileCopyrightText: 2008-2023 Luis Falcón <falcon@gnuhealth.org>
.. SPDX-FileCopyrightText: 2011-2023 GNU Solidario <health@gnusolidario.org>
..
.. SPDX-License-Identifier: CC-BY-SA-4.0

GNU Health Services and orders Module
#####################################

This module allows grouping the services and orders related to a patient
evaluation / encounter and or Hospitalization.

It also permits invoicing the selected orders.


